package Data::Filter::Rule::Variable;
use strict;
use warnings;

#*******************************************************************************
# DOCUMENTATION SECTION
#*******************************************************************************

=head1 NAME

Data::Filter::Rule::Variable - Mentat message filter tree variable node

=head1 SYNOPSIS

 use Data::Filter::Rule::Variable;

=head1 DESCRIPTION



=head1 AUTHOR

 Jan Mach
 Cesnet, z.s.p.o
 jan.mach@cesnet.cz
 http://www.cesnet.cz

=head1 COPYRIGHT

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.


=head1 SEE ALSO

perl(1), Data::Filter::Rule(3), Data::Filter::Rule::Atom(3).

=head1 FUNCTION REFERENCE

=over 4

=cut

#*******************************************************************************
# LIBRARY LOADING SECTION
#*******************************************************************************

#-- Perl core modules ---------------------------------------------------------#
use Carp;
use Scalar::Util 'blessed';

#use Data::Dumper; #--- DEVELOPMENT ONLY ---#
#use Smart::Comments; #--- DEVELOPMENT ONLY ---#

#-- Perl CPAN modules ---------------------------------------------------------#

#-- Custom application modules ------------------------------------------------#
use Data::Filter::Rule::Atom;
use Data::Core qw(:c_dtypes);
use Data::Path::Parser;

#*******************************************************************************
# CONSTANTS AND GLOBAL VARIABLES DEFINITION SECTION
#*******************************************************************************

#-- Constants -----------------------------------------------------------------#

#-- Static public class variables (our) ---------------------------------------#

#-- Static protected class variables (my) -------------------------------------#

#*******************************************************************************
# INITIALIZATION AND CLEANUP SECTION
#*******************************************************************************

#-- Module initializations ----------------------------------------------------#
BEGIN {
    use vars qw($VERSION $DEVEL @ISA);
    $VERSION = '0.1';
    $DEVEL   = 0;
    @ISA     = ('Data::Filter::Rule::Atom');
}


#-- Module clean-up code (global destructor) ----------------------------------#
END {

}

#*******************************************************************************
# IMPLEMENTATION SECTION
#*******************************************************************************

=item datatype(;$) [PUBLIC]

  Usage     : my $result = $rule->datatype($message);
  Purpose   :
  Returns   :
  Arguments :
  Throws    :
  Comments  :
  See Also  :

=cut

sub datatype()
{
    my $self = shift;
    confess "Instance method not invoked on object instance" unless blessed($self);

    return DT_VARIABLE;
}

=item value($) [PUBLIC]

  Usage     : my $result = $rule->value();
  Purpose   :
  Returns   :
  Arguments :
  Throws    :
  Comments  :
  See Also  :

=cut

sub value()
{
    my $self = shift;
    confess "Instance method not invoked on object instance" unless blessed($self);

    return $self->{PATH};
}

#-------------------------------------------------------------------------------

=item to_string() [PUBLIC]

  Usage     : my $result = Data::Filter::Rule->to_string();
  Purpose   :
  Returns   :
  Arguments :
  Throws    :
  Comments  :
  See Also  :

=cut

sub to_string()
{
    my $self = shift;
    confess "Instance method not invoked on object instance" unless blessed($self);

    return "" . $self->value();
}

#-------------------------------------------------------------------------------
# Private interface
#-------------------------------------------------------------------------------

# _init($) [PROTECTED]
#
#  Usage     :
#  Purpose   :
#  Arguments :
#  Returns   :
#  Throws    : Croaks, if invoked on class
#  Comments  :
#  See Also  :

sub _init($)
{
    my $self = shift;
    confess "Instance method not invoked on object instance" unless blessed($self);
    my ($type, $path,) = @_;
    confess "Data path must be defined" unless defined($path);
    confess "Invalid data path '$path' given" unless Data::Path::Parser->validate($path);

    $self->{PATH} = $path;
    return $self;
}

=pod

=back

=cut

1;
