package Mentat::Constants;
use strict;
use warnings;

#*******************************************************************************
# DOCUMENTATION SECTION
#*******************************************************************************

=head1 NAME

Mentat::Constants - Definition of Mentat-wide global constants and

=head1 SYNOPSIS

 use Mentat::Constants;

=head1 DESCRIPTION

Extensive module description

=head1 AUTHOR

 Jan Mach
 Cesnet, z.s.p.o
 jan.mach@cesnet.cz
 http://www.cesnet.cz

=head1 COPYRIGHT

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.

=head1 SEE ALSO

perl(1), Parent::Module(3).

=head1 FUNCTION REFERENCE

=over 4

=cut

#*******************************************************************************
# CONSTANTS AND GLOBAL VARIABLES DEFINITION SECTION
#*******************************************************************************

#-- Constants -----------------------------------------------------------------#

use constant OPERATION_AND => 'AND';
use constant OPERATION_OR  => 'OR';
use constant OPERATION_XOR => 'XOR';

use constant OPERATION_EQ => 'EQ';
use constant OPERATION_NE => 'NE';
use constant OPERATION_GT => 'GT';
use constant OPERATION_LT => 'LT';
use constant OPERATION_GE => 'GE';
use constant OPERATION_LE => 'LE';

use constant OPERATION_LIKE => 'LIKE';

use constant OPERATION_IN => 'IN';

use constant OPERATION_ADD => 'ADD';
use constant OPERATION_SUB => 'SUB';
use constant OPERATION_MUL => 'MUL';
use constant OPERATION_DIV => 'DIV';
use constant OPERATION_MOD => 'MOD';
use constant OPERATION_CON => 'CON';
use constant OPERATION_REP => 'REP';

# !!!! WARNING !!! Some of these datatypes are hardcoded in filter grammar !!!!
# LOW level datatypes
use constant DATATYPE_UNKNOWN   => 'UNKNOWN';
use constant DATATYPE_DEPENDENT => 'DEPENDENT';
use constant DATATYPE_BOOL      => 'BOOL';
use constant DATATYPE_BYTE      => 'BYTE';
use constant DATATYPE_DATETIME  => 'DATETIME';
use constant DATATYPE_ENUM      => 'STRING';
use constant DATATYPE_INT       => 'INT';
use constant DATATYPE_NTPSTAMP  => 'NTPSTAMP';
use constant DATATYPE_PORTLIST  => 'PORTLIST';
use constant DATATYPE_REAL      => 'REAL';
use constant DATATYPE_STRING    => 'STRING';

# HIGH level datatypes
use constant DATATYPE_PERIOD    => 'PERIOD';
use constant DATATYPE_NUMERIC   => 'NUMERIC';
use constant DATATYPE_ADDRESS   => 'ADDRESS';
use constant DATATYPE_IPV4      => 'IPV4';
use constant DATATYPE_IPV6      => 'IPV6';
use constant DATATYPE_MAC       => 'MAC';
use constant DATATYPE_EMAIL     => 'EMAIL';

use constant DATATYPE_IPV4_STR          => 'IPV4-ADDR';
use constant DATATYPE_IPV4_HEX          => 'IPV4-ADDR-HEX';
use constant DATATYPE_IPV4_STR_NET      => 'IPV4-NET';
use constant DATATYPE_IPV4_STR_NET_MASK => 'IPV4-NET-MASK';
use constant DATATYPE_IPV6_STR          => 'IPV6-ADDR';
use constant DATATYPE_IPV6_HEX          => 'IPV6-ADDR-HEX';
use constant DATATYPE_IPV6_STR_NET      => 'IPV6-NET';
use constant DATATYPE_IPV6_STR_NET_MASK => 'IPV6-NET-MASK';

use constant DATATYPE_REGEXP => 'REGEXP';

use constant DATATYPE_BOOL_TRUE => 'TRUE';
use constant DATATYPE_BOOL_FALSE => 'FALSE';

# Some time interval constants
use constant TIME_SEC_DAY   => 86400;
use constant TIME_SEC_WEEK  => 604800;
use constant TIME_SEC_MONTH => 2592000;
use constant TIME_SEC_YEAR  => 31536000;

#-- Static public class variables (our) ---------------------------------------#

#-- Static protected class variables (my) -------------------------------------#

#*******************************************************************************
# INITIALIZATION AND CLEANUP SECTION
#*******************************************************************************

#-- Module initializations ----------------------------------------------------#
BEGIN {
    use vars qw($VERSION $DEVEL);
    $VERSION = '0.1';
    $DEVEL   = 0;
}


#-- Module clean-up code (global destructor) ----------------------------------#
END {

}

#*******************************************************************************
# IMPLEMENTATION SECTION
#*******************************************************************************

# No Implementation in this modile

=pod

=back

=cut

1;
